@@ -6,9 +6,9 @@ namespace TheSeer\Autoload {
         /**
          * @var array
          */
-        private $directories = [];
+        private $directories = array();
 
-        private $seen = [];
+        private $seen = array();
 
         private $pos = 0;
 
@@ -65,7 +65,7 @@ namespace TheSeer\Autoload {
 
             if (isset($jsonData['require'])) {
                 foreach($jsonData['require'] as $entry => $version) {
-                    if ($entry === 'php' || strpos($entry, 'ext-') === 0) {
+                    if ($entry === 'php' || strpos($entry, 'ext-') === 0 || strpos($entry, 'lib-') === 0) {
                         continue;
                     }
                     $this->processRequire($basedir, $entry);
