@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright (c) 2009-2017 Arne Blankerts <arne@blankerts.de>
+ * Copyright (c) 2009-2019 Arne Blankerts <arne@blankerts.de>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification,
@@ -114,7 +114,7 @@ namespace TheSeer\Autoload {
             for($t=0; $t<$tokenCount; $t++) {
                 $current = (array)$this->tokenArray[$t];
 
-                if ($current[0]==T_STRING && $current[1]=='trait' && T_TRAIT==-1) {
+                if ($current[0]===T_STRING && $current[1]==='trait' && T_TRAIT===-1) {
                     // PHP < 5.4 compat fix
                     $current[0] = T_TRAIT_53;
                     $this->tokenArray[$t] = $current;
@@ -135,7 +135,7 @@ namespace TheSeer\Autoload {
 
         private function processBracketClose($pos) {
             $this->bracketLevel--;
-            if ($this->nsBracket != 0 && $this->bracketLevel < $this->nsBracket) {
+            if ($this->nsBracket !== 0 && $this->bracketLevel < $this->nsBracket) {
                 $this->inNamespace = '';
                 $this->nsBracket = 0;
                 $this->aliases = array();
@@ -154,7 +154,7 @@ namespace TheSeer\Autoload {
             $list = array('{');
             $stack = $this->getTokensTill($pos, $list);
             $stackSize = count($stack);
-            $classname = $this->inNamespace != '' ? $this->inNamespace . '\\' : '';
+            $classname = $this->inNamespace !== '' ? $this->inNamespace . '\\' : '';
             $extends = '';
             $extendsFound = false;
             $implementsFound = false;
@@ -166,32 +166,32 @@ namespace TheSeer\Autoload {
                     case T_COMMENT:
                     case T_DOC_COMMENT:
                     case T_WHITESPACE: {
-                        continue;
+                        break;
                     }
                     case T_STRING: {
                         $$mode .= $tok[1];
-                        continue;
+                        break;
                     }
                     case T_NS_SEPARATOR: {
                         $$mode .= '\\';
-                        continue;
+                        break;
                     }
                     case T_EXTENDS: {
                         $extendsFound = true;
                         $mode = 'extends';
-                        continue;
+                        break;
                     }
                     case T_IMPLEMENTS: {
                         $implementsFound = true;
                         $mode = 'implements';
-                        continue;
+                        break;
                     }
                     case ',': {
-                        if ($mode == 'implements') {
+                        if ($mode === 'implements') {
                             $implementsList[] = $this->resolveDependencyName($implements);
                             $implements = '';
                         }
-                        continue;
+                        break;
                     }
                     default: {
                         throw new ParserException(sprintf(
@@ -224,6 +224,12 @@ namespace TheSeer\Autoload {
             $list = array('{');
             $stack = $this->getTokensTill($pos, $list);
             $stackSize = count($stack);
+            $next = $stack[1];
+            if (is_array($next) && $next[0] === '(') {
+                // sort of inline use - ignore
+                return $pos + $stackSize;
+            }
+
             $name = $this->inNamespace != '' ? $this->inNamespace . '\\' : '';
             $extends = '';
             $extendsList = array();
@@ -233,11 +239,11 @@ namespace TheSeer\Autoload {
                     case T_NS_SEPARATOR:
                     case T_STRING: {
                         $$mode .= $tok[1];
-                        continue;
+                        break;
                     }
                     case T_EXTENDS: {
                         $mode = 'extends';
-                        continue;
+                        break;
                     }
                     case ',': {
                         if ($mode == 'extends') {
@@ -307,16 +313,18 @@ namespace TheSeer\Autoload {
             $list = array(';', '{');
             $stack = $this->getTokensTill($pos, $list);
             $stackSize = count($stack);
-            $newpos = $pos + count($stack);
+            $newpos = $pos + $stackSize;
             if ($stackSize < 3) { // empty namespace defintion == root namespace
                 $this->inNamespace = '';
                 $this->aliases = array();
                 return $newpos - 1;
             }
             $next = $stack[1];
-            if (is_array($next) && $next[0] == T_NS_SEPARATOR) { // inline use - ignore
+            if (is_array($next) && ($next[0] === T_NS_SEPARATOR || $next[0] === '(')) {
+                // sort of inline use - ignore
                 return $newpos;
             }
+
             $this->inNamespace = '';
             foreach(array_slice($stack, 1, -1) as $tok) {
                 $this->inNamespace .= $tok[1];
@@ -389,18 +397,18 @@ namespace TheSeer\Autoload {
                                 break;
                             }
                         }
-                        continue;
+                        break;
                     }
                     case ';':
                     case ',': {
                         $this->dependencies[$this->inUnit][] = $this->resolveDependencyName($use);
                         $use = '';
-                        continue;
+                        break;
                     }
                     case T_NS_SEPARATOR:
                     case T_STRING: {
                         $use .= $current[1];
-                        continue;
+                        break;
                     }
                 }
             }
@@ -421,11 +429,11 @@ namespace TheSeer\Autoload {
                     case T_CONST:
                     case T_FUNCTION: {
                         $ignore = true;
-                        continue;
+                        break;
                     }
                     case '{': {
                         $group = $use;
-                        continue;
+                        break;
                     }
                     case ';':
                     case ',': {
@@ -447,16 +455,16 @@ namespace TheSeer\Autoload {
                         $use = $group;
                         $mode = 'use';
                         $ignore = false;
-                        continue;
+                        break;
                     }
                     case T_NS_SEPARATOR:
                     case T_STRING: {
                         $$mode .= $current[1];
-                        continue;
+                        break;
                     }
                     case T_AS: {
                         $mode = 'alias';
-                        continue;
+                        break;
                     }
                 }
             }
@@ -474,6 +482,10 @@ namespace TheSeer\Autoload {
                 return false;
             }
 
+            if ($this->tokenArray[$position + 1] === '(' || $this->tokenArray[$position + 2] === '(') {
+                return false;
+            }
+
             return true;
         }
 
